@@ -19,7 +19,7 @@ from asgiref.local import Local
 from django.conf import settings
 from django.utils.deprecation import RemovedInDjango50Warning
 
-__all__ = [
+__all__ = [  # noqa for utc RemovedInDjango50Warning.
     "utc",
     "get_fixed_timezone",
     "get_default_timezone",
@@ -30,6 +30,7 @@ __all__ = [
     "deactivate",
     "override",
     "localtime",
+    "localdate",
     "now",
     "is_aware",
     "is_naive",
@@ -41,7 +42,18 @@ __all__ = [
 NOT_PASSED = object()
 
 
-utc = timezone.utc
+def __getattr__(name):
+    if name != "utc":
+        raise AttributeError(f"module {__name__!r} has no attribute {name!r}")
+
+    warnings.warn(
+        "The django.utils.timezone.utc alias is deprecated. "
+        "Please update your code to use datetime.timezone.utc instead.",
+        RemovedInDjango50Warning,
+        stacklevel=2,
+    )
+
+    return timezone.utc
 
 
 def get_fixed_timezone(offset):
@@ -56,7 +68,7 @@ def get_fixed_timezone(offset):
 
 # In order to avoid accessing settings at compile time,
 # wrap the logic in a function and cache the result.
-@functools.lru_cache()
+@functools.lru_cache
 def get_default_timezone():
     """
     Return the default time zone as a tzinfo instance.
@@ -224,7 +236,7 @@ def now():
     """
     Return an aware or naive datetime.datetime, depending on settings.USE_TZ.
     """
-    return datetime.now(tz=utc if settings.USE_TZ else None)
+    return datetime.now(tz=timezone.utc if settings.USE_TZ else None)
 
 
 # By design, these four functions don't perform any checks on their arguments.
@@ -322,7 +334,7 @@ def _is_pytz_zone(tz):
     _PYTZ_BASE_CLASSES = (pytz.tzinfo.BaseTzInfo, pytz._FixedOffset)
     # In releases prior to 2018.4, pytz.UTC was not a subclass of BaseTzInfo
     if not isinstance(pytz.UTC, pytz._FixedOffset):
-        _PYTZ_BASE_CLASSES = _PYTZ_BASE_CLASSES + (type(pytz.UTC),)
+        _PYTZ_BASE_CLASSES += (type(pytz.UTC),)
 
     return isinstance(tz, _PYTZ_BASE_CLASSES)
 
@@ -339,3 +351,11 @@ def _datetime_ambiguous_or_imaginary(dt, tz):
             return False
 
     return tz.utcoffset(dt.replace(fold=not dt.fold)) != tz.utcoffset(dt)
+
+
+# RemovedInDjango50Warning.
+_DIR = dir()
+
+
+def __dir__():
+    return sorted([*_DIR, "utc"])
